==> skytemple_files-0.1.0a5-py3-none-any.whl: skytemple_files/dungeon_data/mappa_bin/__init__.py <==
#  Copyright 2020 Parakoopa
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.

MAX_WEIGHT = 10000

XML_MAPPA = 'Mappa'
XML_FLOOR_LIST = 'FloorList'
XML_FLOOR = 'Floor'
XML_FLOOR_LAYOUT = 'FloorLayout'
XML_MONSTER_LIST = 'MonsterList'
XML_MONSTER = 'Monster'
XML_MONSTER__LEVEL = 'level'
XML_MONSTER__WEIGHT = 'weight'
XML_MONSTER__WEIGHT2 = 'weight2'
XML_MONSTER__MD_INDEX = 'id'
XML_TRAP_LIST = 'TrapList'
XML_TRAP = 'Trap'
XML_TRAP__NAME = 'name'
XML_TRAP__WEIGHT = 'weight'
XML_ITEM_LIST = 'ItemList'
XML_ITEM_LIST__TYPE = 'type'
XML_ITEM_LIST__TYPE__FLOOR = 'Floor'
XML_ITEM_LIST__TYPE__SHOP = 'Shop'
XML_ITEM_LIST__TYPE__MONSTER_HOUSE = 'MonsterHouse'
XML_ITEM_LIST__TYPE__BURIED = 'Buried'
XML_ITEM_LIST__TYPE__UNK1 = 'Unk1'
XML_ITEM_LIST__TYPE__UNK2 = 'Unk2'
XML_ITEM = 'Item'
XML_ITEM__ID = 'id'
XML_ITEM__WEIGHT = 'weight'
XML_CATEGORY = 'Category'
XML_CATEGORY__NAME = 'name'
XML_CATEGORY__WEIGHT = 'weight'

# oooh boy
XML_FLOOR_LAYOUT__STRUCTURE = 'structure'
XML_FLOOR_LAYOUT__TILESET = 'tileset'
XML_FLOOR_LAYOUT__BGM = 'bgm'
XML_FLOOR_LAYOUT__WEATHER = 'weather'
XML_FLOOR_LAYOUT__NUMBER = 'number'
XML_FLOOR_LAYOUT__FIXED_FLOOR_ID = 'fixed_floor_id'
XML_FLOOR_LAYOUT__DARKNESS_LEVEL = 'darkness_level'
XML_FLOOR_LAYOUT__GENSET = 'GeneratorSettings'
XML_FLOOR_LAYOUT__GENSET__ROOM_DENSITY = 'room_density'
XML_FLOOR_LAYOUT__GENSET__FLOOR_CONNECTIVITY = 'floor_connectivity'
XML_FLOOR_LAYOUT__GENSET__INITIAL_ENEMY_DENSITY = 'initial_enemy_density'
XML_FLOOR_LAYOUT__GENSET__DEAD_ENDS = 'dead_ends'
XML_FLOOR_LAYOUT__GENSET__ITEM_DENSITY = 'item_density'
XML_FLOOR_LAYOUT__GENSET__TRAP_DENSITY = 'trap_density'
XML_FLOOR_LAYOUT__GENSET__EXTRA_HALLWAY_DENSITY = 'extra_hallway_density'
XML_FLOOR_LAYOUT__GENSET__BURIED_ITEM_DENSITY = 'buried_item_density'
XML_FLOOR_LAYOUT__GENSET__WATER_DENSITY = 'water_density'
XML_FLOOR_LAYOUT__GENSET__MAX_COIN_AMOUNT = 'max_coin_amount'
XML_FLOOR_LAYOUT__CHANCES = 'Chances'
XML_FLOOR_LAYOUT__CHANCES__SHOP = 'shop'
XML_FLOOR_LAYOUT__CHANCES__MONSTER_HOUSE = 'monster_house'
XML_FLOOR_LAYOUT__CHANCES__UNUSED = 'unused'
XML_FLOOR_LAYOUT__CHANCES__STICKY_ITEM = 'sticky_item'
XML_FLOOR_LAYOUT__CHANCES__EMPTY_MONSTER_HOUSE = 'empty_monster_house'
XML_FLOOR_LAYOUT__CHANCES__HIDDEN_STAIRS = 'hidden_stairs'
XML_FLOOR_LAYOUT__TERRAINSET = 'TerrainSettings'
XML_FLOOR_LAYOUT__TERRAINSET__SECONDARY_USED = 'secondary_used'
XML_FLOOR_LAYOUT__TERRAINSET__SECONDARY_TYPE = 'secondary_type'
XML_FLOOR_LAYOUT__TERRAINSET__IMPERFECT_ROOMS = 'imperfect_rooms'
XML_FLOOR_LAYOUT__TERRAINSET__UNK1 = 'unk1'
XML_FLOOR_LAYOUT__TERRAINSET__UNK3 = 'unk3'
XML_FLOOR_LAYOUT__TERRAINSET__UNK4 = 'unk4'
XML_FLOOR_LAYOUT__TERRAINSET__UNK5 = 'unk5'
XML_FLOOR_LAYOUT__TERRAINSET__UNK6 = 'unk6'
XML_FLOOR_LAYOUT__TERRAINSET__UNK7 = 'unk7'
XML_FLOOR_LAYOUT__MISCSET = 'MiscSettings'
XML_FLOOR_LAYOUT__MISCSET__UNKE = 'unkE'
XML_FLOOR_LAYOUT__MISCSET__KECLEON_SHOP_ITEM_POSITIONS = 'kecleon_shop_item_positions'
XML_FLOOR_LAYOUT__MISCSET__UNK_HIDDEN_STAIRS = 'unk_hidden_stairs'
XML_FLOOR_LAYOUT__MISCSET__ENEMY_IQ = 'enemy_iq'
XML_FLOOR_LAYOUT__MISCSET__IQ_BOOSTER_ENABLED = 'iq_booster_enabled'

==> skytemple_files-1.3.4-py3-none-any.whl: skytemple_files/dungeon_data/mappa_bin/__init__.py <==
#  Copyright 2020-2021 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.

MAX_WEIGHT = 10000

XML_MAPPA = 'Mappa'
XML_FLOOR_LIST = 'FloorList'
XML_FLOOR = 'Floor'
XML_FLOOR_LAYOUT = 'FloorLayout'
XML_MONSTER_LIST = 'MonsterList'
XML_MONSTER = 'Monster'
XML_MONSTER__LEVEL = 'level'
XML_MONSTER__WEIGHT = 'weight'
XML_MONSTER__WEIGHT2 = 'weight2'
XML_MONSTER__MD_INDEX = 'id'
XML_TRAP_LIST = 'TrapList'
XML_TRAP = 'Trap'
XML_TRAP__NAME = 'name'
XML_TRAP__WEIGHT = 'weight'
XML_ITEM_LIST = 'ItemList'
XML_ITEM_LIST__TYPE = 'type'
XML_ITEM_LIST__TYPE__FLOOR = 'Floor'
XML_ITEM_LIST__TYPE__SHOP = 'Shop'
XML_ITEM_LIST__TYPE__MONSTER_HOUSE = 'MonsterHouse'
XML_ITEM_LIST__TYPE__BURIED = 'Buried'
XML_ITEM_LIST__TYPE__UNK1 = 'Unk1'
XML_ITEM_LIST__TYPE__UNK2 = 'Unk2'
XML_ITEM = 'Item'
XML_ITEM__ID = 'id'
XML_ITEM__WEIGHT = 'weight'
XML_CATEGORY = 'Category'
XML_CATEGORY__NAME = 'name'
XML_CATEGORY__WEIGHT = 'weight'

# oooh boy
XML_FLOOR_LAYOUT__STRUCTURE = 'structure'
XML_FLOOR_LAYOUT__TILESET = 'tileset'
XML_FLOOR_LAYOUT__BGM = 'bgm'
XML_FLOOR_LAYOUT__WEATHER = 'weather'
XML_FLOOR_LAYOUT__NUMBER = 'number'
XML_FLOOR_LAYOUT__FIXED_FLOOR_ID = 'fixed_floor_id'
XML_FLOOR_LAYOUT__DARKNESS_LEVEL = 'darkness_level'
XML_FLOOR_LAYOUT__GENSET = 'GeneratorSettings'
XML_FLOOR_LAYOUT__GENSET__ROOM_DENSITY = 'room_density'
XML_FLOOR_LAYOUT__GENSET__FLOOR_CONNECTIVITY = 'floor_connectivity'
XML_FLOOR_LAYOUT__GENSET__INITIAL_ENEMY_DENSITY = 'initial_enemy_density'
XML_FLOOR_LAYOUT__GENSET__DEAD_ENDS = 'dead_ends'
XML_FLOOR_LAYOUT__GENSET__ITEM_DENSITY = 'item_density'
XML_FLOOR_LAYOUT__GENSET__TRAP_DENSITY = 'trap_density'
XML_FLOOR_LAYOUT__GENSET__EXTRA_HALLWAY_DENSITY = 'extra_hallway_density'
XML_FLOOR_LAYOUT__GENSET__BURIED_ITEM_DENSITY = 'buried_item_density'
XML_FLOOR_LAYOUT__GENSET__WATER_DENSITY = 'water_density'
XML_FLOOR_LAYOUT__GENSET__MAX_COIN_AMOUNT = 'max_coin_amount'
XML_FLOOR_LAYOUT__CHANCES = 'Chances'
XML_FLOOR_LAYOUT__CHANCES__SHOP = 'shop'
XML_FLOOR_LAYOUT__CHANCES__MONSTER_HOUSE = 'monster_house'
XML_FLOOR_LAYOUT__CHANCES__UNUSED = 'unused'
XML_FLOOR_LAYOUT__CHANCES__STICKY_ITEM = 'sticky_item'
XML_FLOOR_LAYOUT__CHANCES__EMPTY_MONSTER_HOUSE = 'empty_monster_house'
XML_FLOOR_LAYOUT__CHANCES__HIDDEN_STAIRS = 'hidden_stairs'
XML_FLOOR_LAYOUT__TERRAINSET = 'TerrainSettings'
XML_FLOOR_LAYOUT__TERRAINSET__SECONDARY_USED = 'secondary_used'
XML_FLOOR_LAYOUT__TERRAINSET__SECONDARY_TYPE = 'secondary_percentage'
XML_FLOOR_LAYOUT__TERRAINSET__IMPERFECT_ROOMS = 'imperfect_rooms'
XML_FLOOR_LAYOUT__TERRAINSET__UNK1 = 'unk1'
XML_FLOOR_LAYOUT__TERRAINSET__UNK3 = 'unk3'
XML_FLOOR_LAYOUT__TERRAINSET__UNK4 = 'unk4'
XML_FLOOR_LAYOUT__TERRAINSET__UNK5 = 'unk5'
XML_FLOOR_LAYOUT__TERRAINSET__UNK6 = 'unk6'
XML_FLOOR_LAYOUT__TERRAINSET__UNK7 = 'unk7'
XML_FLOOR_LAYOUT__MISCSET = 'MiscSettings'
XML_FLOOR_LAYOUT__MISCSET__UNKE = 'unkE'
XML_FLOOR_LAYOUT__MISCSET__KECLEON_SHOP_ITEM_POSITIONS = 'kecleon_shop_item_positions'
XML_FLOOR_LAYOUT__MISCSET__UNK_HIDDEN_STAIRS = 'unk_hidden_stairs'
XML_FLOOR_LAYOUT__MISCSET__ENEMY_IQ = 'enemy_iq'
XML_FLOOR_LAYOUT__MISCSET__IQ_BOOSTER_BOOST = 'iq_booster_boost'
